@@ -4,7 +4,7 @@ Lookup the MAC address of an ip address
 BSD code
 
 Programmed by Bastian Ballmann
-Last update: 01.12.2004
+Last update: 09.02.2006
 
 This program is free software; you can redistribute 
 it and/or modify it under the terms of the 
@@ -39,7 +39,7 @@ int arp_lookup_bsd(u_char *dev, u_char *ip, char *mac)
   char *lim, *buf, *next;
 
   if(strlen(mac) > 0)
-    strcpy(mac,"unkown");
+    strcpy(mac,"unknown");
   else
     return -1;
 
